;+
; NAME:
;
;   Call_field_lines
;
; PURPOSE:
;
;   Calls produce_field_lines and passes it the information it needs to complete
;
; CALLING SEQUENCE:
;
;   call_field_lines, keyword args
;
; INPUTS:
;   
; KEYWORD ARGUMENTS: 
; trajectory_csv: this argument tells the program to use the ephemeris text file to create field lines. After creating the field lines,
;   the program stores the original spacecraft location as well as the magnetic and centrifugal equator location along that field line. 
; create_maps: this keyword argument takes the locations where analysis was done and produces field lines corresponding to each location.
;      
; Ephemeris_Data - this keyword will use the Ephemeris data set to populate field lines rather than using the Viper analyis
;   
;   
; OUTPUTS:
;
;   This code itself does not return output, the output is generated in produce field lines in the form of csv and or text files.
;
; Notes:
;   Currently the default file being used is V1_Data_CSV.csv. So when create_maps is called, the field lines are only produceded at locations where VIPER
;     analyis was done. 
;
; EXAMPLE:
;   call_field_lines,/trajectory_csv
;
; Created by Kaleb Bodisch

Pro Call_field_lines, create_maps = create_maps, trajectory_csv = trajectory_csv, Ephemeris_Data = Ephemeris_Data, Voyager2 = Voyager2


;store the analyzed data in a structure
 CSV_Data = READ_CSV("V1_Data_CSV.csv", HEADER = CSVHeader)
 if keyword_set(Voyager2) then CSV_Data = READ_CSV("V2_Data_CSV.csv", HEADER = CSVHeader)
 Year         = csv_Data.(0)
 DOY          = csv_Data.(1)
 Hour         = csv_Data.(2)
 Minute       = csv_Data.(3)
 Second       = csv_Data.(4)
 Decimal_Date = DOY + (Hour + (Minute + (Second)/60.0)/60.0)/24.0


   csv_values = transpose([[Decimal_Date],[CSV_Data.field06], [CSV_Data.field07], [CSV_Data.field08]])
   
   ;if we are doing spacecraft trajectory, we want the entire trajectory(taken from iowa ephemeris.)
   ;we can also override the field line maps to be produced from ephemeris data using the ephemeris_data keyword
   if keyword_set(trajectory_csv) or keyword_set(Ephemeris_Data) then begin
    ;ephemeris data taken from http://www-pw.physics.uiowa.edu/~jbg/cas.html using the geographic format
     if not keyword_set(Voyager2) then begin
     OPENR, 1, 'ephemeris_mag.txt' ;this is fairly low resolution(may want to create new file for higher resolution
     eph = DBLARR(12,957)
     endif
     if keyword_set(Voyager2) then begin
     OPENR, 1, 'ephemeris_mag_V2.txt'
     eph = DBLARR(12,3881)
     endif
     READF, 1, eph
     CLOSE, 1
     eph_date = eph[1,*] + (eph[2,*] + (eph[3,*] + (eph[4,*])/60.0)/60.0)/24.0
     eph_long = eph[5,*]
     theta_sc = eph[6,*]
     theta_sc[where(theta_sc gt 0)] = 90.-abs(theta_sc[where(theta_sc gt 0)])
     theta_sc[where(theta_sc lt 0)] = 90.+abs(theta_sc[where(theta_sc lt 0)])
     r_sc = eph[9,*]
     csv_values = transpose([[transpose(eph_date)], [transpose(r_sc)], [transpose(theta_sc)],[transpose(eph_long)]])
   endif

;produce_field_line, csv_values
if keyword_set(create_maps) and keyword_set(trajectory_csv) then produce_field_line, csv_values, /create_maps, /trajectory_csv
if keyword_set(create_maps) and not keyword_set(trajectory_csv) then produce_field_line, csv_values, /create_maps
if keyword_set(trajectory_csv) and not keyword_set(create_maps) then produce_field_line, csv_values, /trajectory_csv

END